@@ -1,7 +1,7 @@
 package DNS::Zone::Struct::Common::BIND;
 
 our $DATE = '2019-09-09'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -142,8 +142,8 @@ sub _sort_records {
 
         # just to be nice: sort by record type: SOA first, then NS, then A, then
         # MX, then the rest
-        my $a_type = $a->{type} eq 'NS' ? 0 : $a->{type} eq 'NS' ? 1 : $a->{type} eq 'A' ? 2 : $a->{type} eq 'MX' ? 3 : $a->{type};
-        my $b_type = $b->{type} eq 'NS' ? 0 : $b->{type} eq 'NS' ? 1 : $b->{type} eq 'A' ? 2 : $b->{type} eq 'MX' ? 3 : $b->{type};
+        my $a_type = $a->{type} eq 'SOA' ? 0 : $a->{type} eq 'NS' ? 1 : $a->{type} eq 'A' ? 2 : $a->{type} eq 'MX' ? 3 : $a->{type};
+        my $b_type = $b->{type} eq 'SOA' ? 0 : $b->{type} eq 'NS' ? 1 : $b->{type} eq 'A' ? 2 : $b->{type} eq 'MX' ? 3 : $b->{type};
         return $cmp if $cmp = $a_type cmp $b_type;
 
         0;
@@ -167,7 +167,7 @@ DNS::Zone::Struct::Common::BIND - BIND-related DNS zone routines
 
 =head1 VERSION
 
-This document describes version 0.002 of DNS::Zone::Struct::Common::BIND (from Perl distribution DNS-Zone-Struct-Common), released on 2019-09-09.
+This document describes version 0.003 of DNS::Zone::Struct::Common::BIND (from Perl distribution DNS-Zone-Struct-Common), released on 2019-09-09.
 
 =head1 SYNOPSIS
 
